# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTIBILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

bl_info = {
    "name" : "Hologram Camera",
    "author" : "Endre Sipos",
    "description" : "Add-on for placing and parametrizing a camera for rendering images needed for a hologram generation. Images shall be rendered with the Render Animation command.",
    "blender" : (2, 82, 0),
    "version" : (1, 3, 0),
    "location" : "View3D > Add > Hologram Camera",
    "warning" : "",
    "category" : "Hologram Camera"
}

if "bpy" in locals():    
    from importlib import reload
    hologram_camera = reload(hologram_camera)

else:    
    from hologramcamera import hologram_camera        

import bpy
from bpy.props import (    
    StringProperty
)

from bpy.types import (
    AddonPreferences
)


class HologramCameraAddonPreferences(AddonPreferences):
    # this must match the addon name, use '__package__'
    # when defining this in a submodule of a python package.
    bl_idname = __name__    

    xml_dir: StringProperty(
        name="XML path",
        description="where hologram XML descriptors will be stored",
        subtype='DIR_PATH',
        default="/tmp\\",
    )

    def draw(self, context):
        layout = self.layout
        layout.prop(self, "xml_dir")

def register():
    bpy.utils.register_class(HologramCameraAddonPreferences)
    hologram_camera.register_addcamera()

def unregister():    
    hologram_camera.unregister_addcamera()
    bpy.utils.unregister_class(HologramCameraAddonPreferences)

if __name__ == "__main__":
    register()